@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12242 2020-05-20 07:23:17Z Trista $
+# $Id: cms_plugins.py 12295 2020-06-02 19:01:46Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-05-20 16:23:17 +0900 (週三, 20 五月 2020) $
-# $Revision: 12242 $
+# $Date: 2020-06-03 04:01:46 +0900 (週三, 03 六月 2020) $
+# $Revision: 12295 $
 
 import datetime
 
@@ -329,7 +329,7 @@ class CallToActionPlugin(CMSPluginBase):
                 page_redirect=redirectPage,
                 form_template=_settings.CALL_TO_ACTION_FORM_DEFAULT_TEMPLATE,
                 plugin_reference=referencedForm,
-                email_subject=_settings.CALL_TO_ACTION_EMAIL_SUBJECT
+                email_subject=_(_settings.CALL_TO_ACTION_EMAIL_SUBJECT),
                 # r
                 # cmsplugin_ptr_id=childPlugin.id
             )
