@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: add_call_to_action_plugin.py 12270 2020-05-26 04:48:53Z Trista $
+# $Id: add_call_to_action_plugin.py 12295 2020-06-02 19:01:46Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-05-26 13:48:53 +0900 (週二, 26 五月 2020) $
-# $Revision: 12270 $
+# $Date: 2020-06-03 04:01:46 +0900 (週三, 03 六月 2020) $
+# $Revision: 12295 $
 
 import datetime
 
@@ -24,6 +24,8 @@ from djangocms_forms.models import Form, FormDefinition
 from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.db import transaction
+from django.utils.translation import gettext_lazy as _
+from django.utils import translation
 
 from Zephyrus.blog_extension.models import CallToActionModel
 from Zephyrus.blog_extension import settings as _settings 
@@ -97,13 +99,15 @@ class Command(BaseCommand):
                     
                     referencedForm = Form(name=name)
                     referencedForm.save()
+                    
+                    translation.activate(cmsPlugin.language)
                     formDefinition = FormDefinition(
                         name=name,
                         success_redirect=True,
                         page_redirect=redirectPage,
                         form_template=_settings.CALL_TO_ACTION_FORM_DEFAULT_TEMPLATE,
                         plugin_reference=referencedForm,
-                        email_subject=_settings.CALL_TO_ACTION_EMAIL_SUBJECT
+                        email_subject=_(_settings.CALL_TO_ACTION_EMAIL_SUBJECT)
                     )
                     formDefinition.save()
 
