@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12270 2020-05-26 04:48:53Z Trista $
+# $Id: views.py 12294 2020-06-02 19:00:43Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-05-26 13:48:53 +0900 (週二, 26 五月 2020) $
-# $Revision: 12270 $
+# $Date: 2020-06-03 04:00:43 +0900 (週三, 03 六月 2020) $
+# $Revision: 12294 $
 
 import datetime
 import hashlib
@@ -27,7 +27,6 @@ import urllib
 
 from bs4 import BeautifulSoup
 from unidecode import unidecode
-from urllib import parse 
 
 from django.contrib import auth
 from django.contrib.sites.models import Site
@@ -48,7 +47,6 @@ from django.urls import reverse
 from django.http import (
     HttpResponseRedirect,
     HttpResponsePermanentRedirect,
-    HttpResponse,
 )
 
 from djangocms_forms.models import FormDefinition
@@ -71,6 +69,7 @@ from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 from Zephyrus.blog_extension.models import CallToActionModel, CallToActionStatistics
 from Zephyrus.blog_extension import settings as _settings
+from Iuppiter.DjangoUtil import getDowloadHttpResponse
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -244,7 +243,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
             replaceStr.update(fileData)
 
             if not form:
-                title = f'[{website.name}]-{_settings.CALL_TO_ACTION_EMAIL_SUBJECT}'  
+                title = f'[{website.name}]-{_(_settings.CALL_TO_ACTION_EMAIL_SUBJECT)}'  
 
             else:
                 title = f'[{website.name}]-{landingForm.email_subject}'
@@ -338,26 +337,7 @@ def showTargetFile(request):
             targetFile = callToActionStatistics.action.targetFile
 
             path = settings.MEDIA_URL + str(targetFile.file)
-            with open(path[1:], 'rb') as f:
-                file = f.read()
-                
-            mimeType = mimetypes.guess_type(targetFile.original_filename)
-            if mimeType is not None:
-                contentType = mimeType[0] + ';charset=utf-8'
-            else:
-                contentType = 'application/force-download;charset=utf-8'
-            if callToActionStatistics.action.fileName:
-                fileName = callToActionStatistics.action.fileName + '.' +targetFile.original_filename.split('.')[-1]
-            else:
-                fileName = targetFile.original_filename
-            response = HttpResponse(
-                file,
-                content_type=contentType
-            )
-            safeFileName = parse.quote(fileName)
-            response['Content-Disposition'] = (
-                        f"attachment; filename={safeFileName}; filename*={safeFileName}")
-            response['Content-Transfer-Encoding'] = 'binary'
+            response = getDowloadHttpResponse(path[1:], name=callToActionStatistics.action.fileName)
             return response
 
         elif callToActionStatistics.action.linkUrl:
@@ -375,7 +355,8 @@ def showTargetFile(request):
             if callToActionStatistics.article:
                 article = callToActionStatistics.article
                 articleId = int_to_hashid(article.pk)
-                fileName = f'[{websiteName}]{article.slug}.pdf'
+                name = f'[{websiteName}]{article.slug}'
+                fileName = f'{name}.pdf'
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
                 
                 try:
@@ -402,8 +383,9 @@ def showTargetFile(request):
                 title = soup.find('title')
                 title = title.text.replace(' ', '')
                 title = title.replace('\n', '-')
-
-                fileName = f"[{title}].pdf"
+                
+                name = f"[{title}]"
+                fileName = f"{name}.pdf"
 
 
                 path = settings.MEDIA_URL + PDF_ROOT + fileName
@@ -414,18 +396,7 @@ def showTargetFile(request):
                     path[1:],
                     configuration=config,
                 )
-            with open(path[1:], 'rb') as f:
-                file = f.read()
-            response = HttpResponse(
-                file,
-                content_type='application/pdf;charset=utf-8'
-            )
-            
-            safeFileName = parse.quote(fileName)
-            response['Content-Disposition'] = (
-                        f"attachment; filename={safeFileName}; filename*={safeFileName}")
-            response['Content-Transfer-Encoding'] = 'binary'
-
+            response = getDowloadHttpResponse(path[1:], name=name)
             return response
 
     key = request.GET.get('key')
